==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/EmptyDirVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface EmptyDirVolumeSourceFluent<A extends io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getMedium();
  public A withMedium(java.lang.String medium);
  public java.lang.Boolean hasMedium();
  
  /**
   * Method is deprecated. use withMedium instead.
   */
  @java.lang.Deprecated
  public A withNewMedium(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildSizeLimit instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.Quantity getSizeLimit();
  public io.fabric8.kubernetes.api.model.Quantity buildSizeLimit();
  public A withSizeLimit(io.fabric8.kubernetes.api.model.Quantity sizeLimit);
  public java.lang.Boolean hasSizeLimit();
  public A withNewSizeLimit(java.lang.String amount,java.lang.String format);
  public A withNewSizeLimit(java.lang.String amount);
  public io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent.SizeLimitNested<A> withNewSizeLimit();
  public io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent.SizeLimitNested<A> withNewSizeLimitLike(io.fabric8.kubernetes.api.model.Quantity item);
  public io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent.SizeLimitNested<A> editSizeLimit();
  public io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent.SizeLimitNested<A> editOrNewSizeLimit();
  public io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent.SizeLimitNested<A> editOrNewSizeLimitLike(io.fabric8.kubernetes.api.model.Quantity item);
  
 /**
  * Quantity is fixed point representation of a number.
  * It provides convenient marshalling/unmarshalling in JSON or YAML,
  * in addition to String or getAmountInBytes accessors.
  */
public interface SizeLimitNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.QuantityFluent<io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent.SizeLimitNested<N>>{
    public N and();
    public N endSizeLimit();
    
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/EmptyDirVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface EmptyDirVolumeSourceFluent<A extends io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getMedium();
  public A withMedium(java.lang.String medium);
  public java.lang.Boolean hasMedium();
  
  /**
   * Method is deprecated. use withMedium instead.
   */
  @java.lang.Deprecated
  public A withNewMedium(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildSizeLimit instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.Quantity getSizeLimit();
  public io.fabric8.kubernetes.api.model.Quantity buildSizeLimit();
  public A withSizeLimit(io.fabric8.kubernetes.api.model.Quantity sizeLimit);
  public java.lang.Boolean hasSizeLimit();
  public A withNewSizeLimit(java.lang.String amount,java.lang.String format);
  public A withNewSizeLimit(java.lang.String amount);
  public io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent.SizeLimitNested<A> withNewSizeLimit();
  public io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent.SizeLimitNested<A> withNewSizeLimitLike(io.fabric8.kubernetes.api.model.Quantity item);
  public io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent.SizeLimitNested<A> editSizeLimit();
  public io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent.SizeLimitNested<A> editOrNewSizeLimit();
  public io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent.SizeLimitNested<A> editOrNewSizeLimitLike(io.fabric8.kubernetes.api.model.Quantity item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
 /**
  * Quantity is fixed point representation of a number.
  * It provides convenient marshalling/unmarshalling in JSON or YAML,
  * in addition to String or getAmountInBytes accessors.
  */
public interface SizeLimitNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.QuantityFluent<io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent.SizeLimitNested<N>>{
    public N and();
    public N endSizeLimit();
    
  }
  
}
